#
# spec file for package hyprlock
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
  %define _pam_confdir %{_pam_vendordir}
  %define _config_norepl %nil
%else
  %define _pam_confdir %{_sysconfdir}
  %define _config_norepl %config(noreplace)
%endif

Name:           hyprlock
Version:        0.4.1
Release:        1.4
Summary:        Hyprland's screen locking utility
License:        BSD-3-Clause
URL:            https://wiki.hyprland.org/Hypr-Ecosystem/hyprlock/
Source0:        %{name}-%{version}.tar.xz
Source1:        hyprlock.conf
BuildRequires:  Mesa-devel
BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(hyprlang) >= 0.4.2
BuildRequires:  pkgconfig(hyprutils)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libmagic)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(pam)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(xkbcommon)

%description
Hyprland's simple, yet multi-threaded and GPU-accelerated screen locking utility.

* uses the secure ext-session-lock protocol
* full support for fractional-scale
* fully GPU accelerated
* multi-threaded resource acquisition for no hitches

%prep
%autosetup -p1
# Both _pam_confdir paths provide a pam.d path
sed -i 's/pam.d//' CMakeLists.txt

%build
%cmake \
  -D CMAKE_INSTALL_SYSCONFDIR=%{_pam_confdir} \
  -D CMAKE_BUILD_TYPE=Release
%cmake_build

%install
%cmake_install
install -Dm 0644 %{SOURCE1} %{buildroot}/%{_docdir}/%{name}/hyprlock.conf.example

%files
%license LICENSE
%doc README.md hyprlock.conf.example
%_config_norepl %{_pam_confdir}/hyprlock
%{_bindir}/hyprlock

%changelog
* Mon Aug 12 2024 Krzysztof Wiktorczyk <magu44@gmail.com>
- Update to version 0.4.0:
  * hyprlock: ensure members are accessed direct
  * "LockSurface: Some bug fixing
  * core: add option to render solid background immediatly when bg
    assets are not ready
  * core: handle missing wayland protocol support
  * readme: add official repo package to arch install
  * [Draft] auth: don't start pam conversation before the initial
    input happens
  * Label exception handling + Frambuffer checks + headers
  * config: add input-field fail_timeout option
  * asyncResourceGatherer: trace logs and exit behaviour
  * core: handle ext_session_lock_v1::finished as defined by the
    protocol
  * core: immediately create session lock surfaces
  * Config: use hyprutils helper
  * core: grace unlock improvements and auth fixes for grace/SIGUSR1
    unlocks
  * core: make sure m_sLockState.lock is present in onLockFinished and
    releaseSessionLock
  * asyncResourceGatherer: deduplicate image rendering code
* Sun Jul  7 2024 Joshua Smith <smolsheep@opensuse.org>
- Add new BuildRequires: libjpeg, libwebp, libmagic
- Remove always-install-pam.patch -- Fixed upstream
- Update to version 0.4.0:
  * core: avoid double unlocks with no_fade_out
  * input-field: fade in when checkWaiting is true
  * core: use --immediate for attemptRestoreOnDeath
  * widgets: add Shape + minor image improve
  * auth: implement a full pam conversation
  * input-field: increase default fade_timeout
  * label: add text_align option for multi-line text
  * fix initialization issues in LockSurface
  * Add support for JPEG and WEBP background images
  * readme: add new line for clarity
  * add libmagic dependency to README
  * renderer: add text trim with option to disable
  * gatherer: use absolute path in magic guess
  * Fixed getconf command in build instructions
  * core: add key repeat for backspace and make del clear the input
  * add zindex option to widgets
  * cmake: macro-prefix-map, compile_commands.json
  * few reported leaks by asan
  * handle null timers in destructors
  * readme: Add Arch instructions
  * core: move to hyprutils for utils
  * fix second instance of hyprlock unlocking session
  * Inproved error handling and arg parsing
  * core: stabilize label updates and revision locking in the
    asyncResourceGatherer
  * core: fix sourcing config files
  * core: improve dynamic output handling
  * asyncResourceGatherer: add dma frames before starting the
    asyncLoopThread
  * Remove dupe input-field rounding from
    listKeysForSpecialCategory
  * label: do not error when using cmd[] for a static label cmd
  * config: don't crash when getenv HOME returns null
  * auth: pam fallback log message and always call pam_end after
    pam_authenticate
  * helpers: fix jpeg and webp OOM error
* Thu Jun  6 2024 Joshua Smith <smolsheep@opensuse.org>
- Move PAM to /usr -- Fixes filelist-forbidden-move-to-usr badness
- Change parts of _service to run at buildtime instead to properly
  utilize the obscpio
- Update to version 0.3.0:
  * asyncResourceGatherer: skip processing screenshot paths and
    remove initThread
  * label: add $FAIL and $ATTEMPTS
  * core: mmap keymap buffer with MAP_PRIVATE
  * renderer, Nix/HM module: add fade out animation and property to
    disable
  * input-field: fix missing fail_text when placeholder_text is
    empty
  * core: fix libc++ compatibility
  * core: fade out improvements
  * widgets: add Image
  * input-field: various fixes
  * Add missing destructors causing segfaults
  * config: add -c, --config commandline options
  * input-field: new color features
  * input-field: only render the current output on fade out
    callback
  * Use getpwuid(getuid()) instead of getlogin()
  * label: add $LAYOUT variable
  * Nix/HM module: empty defaults for images and labels
  * config: add option to ignore empty input
  * config: allow mon description for monitor value
  * README: fix a typo
  * Make Ctrl+u clear password input
  * label: destroy texture
  * Nix/HM module: add sources and extraConfig
  * Nix/HM module: add ignore_empty_input option
  * widgets: add rotate option to label and image
  * Nix/HM module: fix rotate options
  * widgets: add user description variable
  * nix/hm-module: add shadowable to images
  * image: add reload options
* Thu Apr  4 2024 Michal Hrusecky <michal.hrusecky@opensuse.org>
- Initial package of hyprlock - version 0.2.0
